Class: Api::ChargeResult

Inherits:
Object
  • Object
show all
Defined in:
lib/jamm/api/models/v1_charge_result.rb

Overview

Contains the result of a charge operation.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ChargeResult

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/jamm/api/models/v1_charge_result.rb', line 136

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Api::ChargeResult` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Api::ChargeResult`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'charge_id')
    self.charge_id = attributes[:'charge_id']
  end

  if attributes.key?(:'paid')
    self.paid = attributes[:'paid']
  end

  if attributes.key?(:'reason')
    self.reason = attributes[:'reason']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'merchant_name')
    self.merchant_name = attributes[:'merchant_name']
  end

  if attributes.key?(:'initial_amount')
    self.initial_amount = attributes[:'initial_amount']
  end

  if attributes.key?(:'discount')
    self.discount = attributes[:'discount']
  end

  if attributes.key?(:'final_amount')
    self.final_amount = attributes[:'final_amount']
  end

  if attributes.key?(:'amount_refunded')
    self.amount_refunded = attributes[:'amount_refunded']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'token_id')
    self.token_id = attributes[:'token_id']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'processed_at')
    self.processed_at = attributes[:'processed_at']
  end

  if attributes.key?(:'charge_status')
    self.charge_status = attributes[:'charge_status']
  else
    self.charge_status = 'CHARGE_STATUS_UNSPECIFIED'
  end

  if attributes.key?(:'error')
    self.error = attributes[:'error']
  end
end

Instance Attribute Details

#amount_refundedObject

Returns the value of attribute amount_refunded.



37
38
39
# File 'lib/jamm/api/models/v1_charge_result.rb', line 37

def amount_refunded
  @amount_refunded
end

#charge_idObject

Returns the value of attribute charge_id.



19
20
21
# File 'lib/jamm/api/models/v1_charge_result.rb', line 19

def charge_id
  @charge_id
end

#charge_statusObject

Returns the value of attribute charge_status.



51
52
53
# File 'lib/jamm/api/models/v1_charge_result.rb', line 51

def charge_status
  @charge_status
end

#created_atObject

Returns the value of attribute created_at.



45
46
47
# File 'lib/jamm/api/models/v1_charge_result.rb', line 45

def created_at
  @created_at
end

#currencyObject

Returns the value of attribute currency.



39
40
41
# File 'lib/jamm/api/models/v1_charge_result.rb', line 39

def currency
  @currency
end

#descriptionObject

Returns the value of attribute description.



27
28
29
# File 'lib/jamm/api/models/v1_charge_result.rb', line 27

def description
  @description
end

#discountObject

Returns the value of attribute discount.



33
34
35
# File 'lib/jamm/api/models/v1_charge_result.rb', line 33

def discount
  @discount
end

#errorObject

Returns the value of attribute error.



53
54
55
# File 'lib/jamm/api/models/v1_charge_result.rb', line 53

def error
  @error
end

#final_amountObject

Returns the value of attribute final_amount.



35
36
37
# File 'lib/jamm/api/models/v1_charge_result.rb', line 35

def final_amount
  @final_amount
end

#initial_amountObject

Returns the value of attribute initial_amount.



31
32
33
# File 'lib/jamm/api/models/v1_charge_result.rb', line 31

def initial_amount
  @initial_amount
end

#merchant_nameObject

Returns the value of attribute merchant_name.



29
30
31
# File 'lib/jamm/api/models/v1_charge_result.rb', line 29

def merchant_name
  @merchant_name
end

#metadataObject

Returns the value of attribute metadata.



43
44
45
# File 'lib/jamm/api/models/v1_charge_result.rb', line 43

def 
  @metadata
end

True when charged.



22
23
24
# File 'lib/jamm/api/models/v1_charge_result.rb', line 22

def paid
  @paid
end

#processed_atObject

Returns the value of attribute processed_at.



49
50
51
# File 'lib/jamm/api/models/v1_charge_result.rb', line 49

def processed_at
  @processed_at
end

#reasonObject

Reason contains enum status in string. Merchant should not write any code depending on the reason, because Jamm may update the reason at any time.



25
26
27
# File 'lib/jamm/api/models/v1_charge_result.rb', line 25

def reason
  @reason
end

#token_idObject

Returns the value of attribute token_id.



41
42
43
# File 'lib/jamm/api/models/v1_charge_result.rb', line 41

def token_id
  @token_id
end

#updated_atObject

Returns the value of attribute updated_at.



47
48
49
# File 'lib/jamm/api/models/v1_charge_result.rb', line 47

def updated_at
  @updated_at
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
# File 'lib/jamm/api/models/v1_charge_result.rb', line 300

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Api.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



101
102
103
# File 'lib/jamm/api/models/v1_charge_result.rb', line 101

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/jamm/api/models/v1_charge_result.rb', line 78

def self.attribute_map
  {
    :'charge_id' => :'chargeId',
    :'paid' => :'paid',
    :'reason' => :'reason',
    :'description' => :'description',
    :'merchant_name' => :'merchantName',
    :'initial_amount' => :'initialAmount',
    :'discount' => :'discount',
    :'final_amount' => :'finalAmount',
    :'amount_refunded' => :'amountRefunded',
    :'currency' => :'currency',
    :'token_id' => :'tokenId',
    :'metadata' => :'metadata',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt',
    :'processed_at' => :'processedAt',
    :'charge_status' => :'chargeStatus',
    :'error' => :'error'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/jamm/api/models/v1_charge_result.rb', line 276

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



129
130
131
132
# File 'lib/jamm/api/models/v1_charge_result.rb', line 129

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/jamm/api/models/v1_charge_result.rb', line 106

def self.openapi_types
  {
    :'charge_id' => :'String',
    :'paid' => :'Boolean',
    :'reason' => :'String',
    :'description' => :'String',
    :'merchant_name' => :'String',
    :'initial_amount' => :'Integer',
    :'discount' => :'Integer',
    :'final_amount' => :'Integer',
    :'amount_refunded' => :'Integer',
    :'currency' => :'String',
    :'token_id' => :'String',
    :'metadata' => :'Hash<String, String>',
    :'created_at' => :'Time',
    :'updated_at' => :'Time',
    :'processed_at' => :'Time',
    :'charge_status' => :'ChargeStatus',
    :'error' => :'ChargeError'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/jamm/api/models/v1_charge_result.rb', line 239

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      charge_id == o.charge_id &&
      paid == o.paid &&
      reason == o.reason &&
      description == o.description &&
      merchant_name == o.merchant_name &&
      initial_amount == o.initial_amount &&
      discount == o.discount &&
      final_amount == o.final_amount &&
      amount_refunded == o.amount_refunded &&
      currency == o.currency &&
      token_id == o.token_id &&
       == o. &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      processed_at == o.processed_at &&
      charge_status == o.charge_status &&
      error == o.error
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



371
372
373
374
375
376
377
378
379
380
381
382
383
# File 'lib/jamm/api/models/v1_charge_result.rb', line 371

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


263
264
265
# File 'lib/jamm/api/models/v1_charge_result.rb', line 263

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



269
270
271
# File 'lib/jamm/api/models/v1_charge_result.rb', line 269

def hash
  [charge_id, paid, reason, description, merchant_name, initial_amount, discount, final_amount, amount_refunded, currency, token_id, , created_at, updated_at, processed_at, charge_status, error].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



224
225
226
227
228
# File 'lib/jamm/api/models/v1_charge_result.rb', line 224

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



347
348
349
# File 'lib/jamm/api/models/v1_charge_result.rb', line 347

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



353
354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/jamm/api/models/v1_charge_result.rb', line 353

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



341
342
343
# File 'lib/jamm/api/models/v1_charge_result.rb', line 341

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



232
233
234
235
# File 'lib/jamm/api/models/v1_charge_result.rb', line 232

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end