Class: Api::Customer

Inherits:
Object
  • Object
show all
Defined in:
lib/jamm/api/models/v1_customer.rb,
lib/jamm/api_patches.rb

Overview

Customer object.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Customer

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/jamm/api/models/v1_customer.rb', line 76

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Api::Customer` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Api::Customer`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'link_initialized')
    self.link_initialized = attributes[:'link_initialized']
  end

  if attributes.key?(:'activated')
    self.activated = attributes[:'activated']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'bank_information')
    self.bank_information = attributes[:'bank_information']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#activatedObject

Returns the value of attribute activated.



25
26
27
# File 'lib/jamm/api/models/v1_customer.rb', line 25

def activated
  @activated
end

#bank_informationObject

Returns the value of attribute bank_information.



29
30
31
# File 'lib/jamm/api/models/v1_customer.rb', line 29

def bank_information
  @bank_information
end

#created_atObject

Returns the value of attribute created_at.



31
32
33
# File 'lib/jamm/api/models/v1_customer.rb', line 31

def created_at
  @created_at
end

#emailObject

Returns the value of attribute email.



21
22
23
# File 'lib/jamm/api/models/v1_customer.rb', line 21

def email
  @email
end

#idObject

Returns the value of attribute id.



19
20
21
# File 'lib/jamm/api/models/v1_customer.rb', line 19

def id
  @id
end

Returns the value of attribute link_initialized.



23
24
25
# File 'lib/jamm/api/models/v1_customer.rb', line 23

def link_initialized
  @link_initialized
end

#statusObject

Returns the value of attribute status.



27
28
29
# File 'lib/jamm/api/models/v1_customer.rb', line 27

def status
  @status
end

#updated_atObject

Returns the value of attribute updated_at.



33
34
35
# File 'lib/jamm/api/models/v1_customer.rb', line 33

def updated_at
  @updated_at
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/jamm/api/models/v1_customer.rb', line 191

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Api.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/jamm/api/models/v1_customer.rb', line 50

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
46
47
# File 'lib/jamm/api/models/v1_customer.rb', line 36

def self.attribute_map
  {
    :'id' => :'id',
    :'email' => :'email',
    :'link_initialized' => :'linkInitialized',
    :'activated' => :'activated',
    :'status' => :'status',
    :'bank_information' => :'bankInformation',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/jamm/api/models/v1_customer.rb', line 167

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



69
70
71
72
# File 'lib/jamm/api/models/v1_customer.rb', line 69

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/jamm/api/models/v1_customer.rb', line 55

def self.openapi_types
  {
    :'id' => :'String',
    :'email' => :'String',
    :'link_initialized' => :'Boolean',
    :'activated' => :'Boolean',
    :'status' => :'Apiv1Status',
    :'bank_information' => :'BankInformation',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/jamm/api/models/v1_customer.rb', line 139

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      email == o.email &&
      link_initialized == o.link_initialized &&
      activated == o.activated &&
      status == o.status &&
      bank_information == o.bank_information &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/jamm/api/models/v1_customer.rb', line 262

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#charges(pagination: nil) ⇒ Object

Allow to drill down to list charges. e.g. cus.charges –> []



7
8
9
10
11
12
# File 'lib/jamm/api_patches.rb', line 7

def charges(pagination: nil)
  Jamm::Payment.list(
    customer: id,
    pagination: pagination
  )
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


154
155
156
# File 'lib/jamm/api/models/v1_customer.rb', line 154

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



160
161
162
# File 'lib/jamm/api/models/v1_customer.rb', line 160

def hash
  [id, email, link_initialized, activated, status, bank_information, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



124
125
126
127
128
# File 'lib/jamm/api/models/v1_customer.rb', line 124

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



238
239
240
# File 'lib/jamm/api/models/v1_customer.rb', line 238

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/jamm/api/models/v1_customer.rb', line 244

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



232
233
234
# File 'lib/jamm/api/models/v1_customer.rb', line 232

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



132
133
134
135
# File 'lib/jamm/api/models/v1_customer.rb', line 132

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end