Class: Api::PaymentApi

Inherits:
Object
  • Object
show all
Defined in:
lib/jamm/api/api/payment_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ PaymentApi

Returns a new instance of PaymentApi.



19
20
21
# File 'lib/jamm/api/api/payment_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/jamm/api/api/payment_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#add_charge(body, opts = {}) ⇒ AddChargeResponse

Use existing contract with charge Use existing contract with charge

Parameters:

  • body (AddChargeRequest)

    This message represents a request to add a charge to an existing customer. It contains all necessary information to process a new payment transaction.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



27
28
29
30
# File 'lib/jamm/api/api/payment_api.rb', line 27

def add_charge(body, opts = {})
  data, _status_code, _headers = add_charge_with_http_info(body, opts)
  data
end

#add_charge_with_http_info(body, opts = {}) ⇒ Array<(AddChargeResponse, Integer, Hash)>

Use existing contract with charge Use existing contract with charge

Parameters:

  • body (AddChargeRequest)

    This message represents a request to add a charge to an existing customer. It contains all necessary information to process a new payment transaction.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(AddChargeResponse, Integer, Hash)>)

    AddChargeResponse data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/jamm/api/api/payment_api.rb', line 37

def add_charge_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PaymentApi.add_charge ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling PaymentApi.add_charge"
  end
  # resource path
  local_var_path = '/v1/add-charge'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'AddChargeResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"PaymentApi.add_charge",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentApi#add_charge\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#async_off_session_payment(body, opts = {}) ⇒ OffSessionPaymentAsyncResponse

Initiate async off-session payment Starts asynchronous off-session payment processing and returns request tracking information.

Parameters:

  • body (OffSessionPaymentAsyncRequest)

    This message represents a request to process an off-session payment asynchronously. It contains the customer ID and the amount to charge. Supports triggerError in charge.metadata for test error simulation. See InitialCharge.metadata.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



95
96
97
98
# File 'lib/jamm/api/api/payment_api.rb', line 95

def async_off_session_payment(body, opts = {})
  data, _status_code, _headers = async_off_session_payment_with_http_info(body, opts)
  data
end

#async_off_session_payment_with_http_info(body, opts = {}) ⇒ Array<(OffSessionPaymentAsyncResponse, Integer, Hash)>

Initiate async off-session payment Starts asynchronous off-session payment processing and returns request tracking information.

Parameters:

  • body (OffSessionPaymentAsyncRequest)

    This message represents a request to process an off-session payment asynchronously. It contains the customer ID and the amount to charge. Supports triggerError in charge.metadata for test error simulation. See InitialCharge.metadata.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/jamm/api/api/payment_api.rb', line 105

def async_off_session_payment_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PaymentApi.async_off_session_payment ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling PaymentApi.async_off_session_payment"
  end
  # resource path
  local_var_path = '/v1/payments/off-session/async'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'OffSessionPaymentAsyncResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"PaymentApi.async_off_session_payment",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentApi#async_off_session_payment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_contract_with_charge(body, opts = {}) ⇒ CreateContractWithChargeResponse

Create a contract with initial charge Create a contract with initial charge

Parameters:

  • body (CreateContractWithChargeRequest)

    Request message for creating a new contract with an immediate initial charge. This combines contract creation and charging in a single operation.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



163
164
165
166
# File 'lib/jamm/api/api/payment_api.rb', line 163

def create_contract_with_charge(body, opts = {})
  data, _status_code, _headers = create_contract_with_charge_with_http_info(body, opts)
  data
end

#create_contract_with_charge_with_http_info(body, opts = {}) ⇒ Array<(CreateContractWithChargeResponse, Integer, Hash)>

Create a contract with initial charge Create a contract with initial charge

Parameters:

  • body (CreateContractWithChargeRequest)

    Request message for creating a new contract with an immediate initial charge. This combines contract creation and charging in a single operation.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/jamm/api/api/payment_api.rb', line 173

def create_contract_with_charge_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PaymentApi.create_contract_with_charge ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling PaymentApi.create_contract_with_charge"
  end
  # resource path
  local_var_path = '/v1/contract-with-charge'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'CreateContractWithChargeResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"PaymentApi.create_contract_with_charge",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentApi#create_contract_with_charge\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_contract_without_charge(body, opts = {}) ⇒ CreateContractWithoutChargeResponse

Create a contract without initial charge (contract only) Create a contract without initial charge (contract only)

Parameters:

  • body (CreateContractWithoutChargeRequest)

    Request message for creating a new contract without an initial charge. This is typically used when setting up a billing relationship before any actual charges are processed.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



231
232
233
234
# File 'lib/jamm/api/api/payment_api.rb', line 231

def create_contract_without_charge(body, opts = {})
  data, _status_code, _headers = create_contract_without_charge_with_http_info(body, opts)
  data
end

#create_contract_without_charge_with_http_info(body, opts = {}) ⇒ Array<(CreateContractWithoutChargeResponse, Integer, Hash)>

Create a contract without initial charge (contract only) Create a contract without initial charge (contract only)

Parameters:

  • body (CreateContractWithoutChargeRequest)

    Request message for creating a new contract without an initial charge. This is typically used when setting up a billing relationship before any actual charges are processed.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/jamm/api/api/payment_api.rb', line 241

def create_contract_without_charge_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PaymentApi.create_contract_without_charge ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling PaymentApi.create_contract_without_charge"
  end
  # resource path
  local_var_path = '/v1/contract-without-charge'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'CreateContractWithoutChargeResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"PaymentApi.create_contract_without_charge",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentApi#create_contract_without_charge\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_charge(charge, opts = {}) ⇒ GetChargeResponse

Get a specific charge Get a specific charge information

Parameters:

  • charge (String)

    @gotags: validate:&quot;required&quot;

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



299
300
301
302
# File 'lib/jamm/api/api/payment_api.rb', line 299

def get_charge(charge, opts = {})
  data, _status_code, _headers = get_charge_with_http_info(charge, opts)
  data
end

#get_charge_with_http_info(charge, opts = {}) ⇒ Array<(GetChargeResponse, Integer, Hash)>

Get a specific charge Get a specific charge information

Parameters:

  • charge (String)

    @gotags: validate:&quot;required&quot;

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(GetChargeResponse, Integer, Hash)>)

    GetChargeResponse data, response status code and response headers



309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/jamm/api/api/payment_api.rb', line 309

def get_charge_with_http_info(charge, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PaymentApi.get_charge ...'
  end
  # verify the required parameter 'charge' is set
  if @api_client.config.client_side_validation && charge.nil?
    fail ArgumentError, "Missing the required parameter 'charge' when calling PaymentApi.get_charge"
  end
  # resource path
  local_var_path = '/v1/charge/{charge}'.sub('{' + 'charge' + '}', CGI.escape(charge.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetChargeResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"PaymentApi.get_charge",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentApi#get_charge\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_charges(customer, opts = {}) ⇒ GetChargesResponse

Get a list of charges Get a list of charges for a customer

Parameters:

  • customer (String)

    @gotags: validate:&quot;required&quot;

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :pagination_page_size (Integer)
  • :pagination_page_token (String)

Returns:



364
365
366
367
# File 'lib/jamm/api/api/payment_api.rb', line 364

def get_charges(customer, opts = {})
  data, _status_code, _headers = get_charges_with_http_info(customer, opts)
  data
end

#get_charges_with_http_info(customer, opts = {}) ⇒ Array<(GetChargesResponse, Integer, Hash)>

Get a list of charges Get a list of charges for a customer

Parameters:

  • customer (String)

    @gotags: validate:&quot;required&quot;

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :pagination_page_size (Integer)
  • :pagination_page_token (String)

Returns:

  • (Array<(GetChargesResponse, Integer, Hash)>)

    GetChargesResponse data, response status code and response headers



376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
# File 'lib/jamm/api/api/payment_api.rb', line 376

def get_charges_with_http_info(customer, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PaymentApi.get_charges ...'
  end
  # verify the required parameter 'customer' is set
  if @api_client.config.client_side_validation && customer.nil?
    fail ArgumentError, "Missing the required parameter 'customer' when calling PaymentApi.get_charges"
  end
  # resource path
  local_var_path = '/v1/charges/{customer}'.sub('{' + 'customer' + '}', CGI.escape(customer.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'pagination.pageSize'] = opts[:'pagination_page_size'] if !opts[:'pagination_page_size'].nil?
  query_params[:'pagination.pageToken'] = opts[:'pagination_page_token'] if !opts[:'pagination_page_token'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetChargesResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"PaymentApi.get_charges",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentApi#get_charges\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#internal_withdraw_async(body, opts = {}) ⇒ WithdrawAsyncResponse

Initiate async withdraw (internal) Internal-only endpoint for initiating asynchronous withdrawal processing.

Parameters:

  • body (WithdrawAsyncRequest)

    This message represents a request to withdraw money from a customer asynchronously. It contains the customer ID and the amount to withdraw. Supports triggerError in charge.metadata for test error simulation. See InitialCharge.metadata.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



431
432
433
434
# File 'lib/jamm/api/api/payment_api.rb', line 431

def internal_withdraw_async(body, opts = {})
  data, _status_code, _headers = internal_withdraw_async_with_http_info(body, opts)
  data
end

#internal_withdraw_async_status(body, opts = {}) ⇒ WithdrawAsyncStatusResponse

Get async withdraw status (internal) Internal-only endpoint for retrieving async withdraw processing status.

Parameters:

  • body (WithdrawAsyncStatusRequest)

    This message represents a request to get the status of an asynchronous withdrawal.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



499
500
501
502
# File 'lib/jamm/api/api/payment_api.rb', line 499

def internal_withdraw_async_status(body, opts = {})
  data, _status_code, _headers = internal_withdraw_async_status_with_http_info(body, opts)
  data
end

#internal_withdraw_async_status_with_http_info(body, opts = {}) ⇒ Array<(WithdrawAsyncStatusResponse, Integer, Hash)>

Get async withdraw status (internal) Internal-only endpoint for retrieving async withdraw processing status.

Parameters:

  • body (WithdrawAsyncStatusRequest)

    This message represents a request to get the status of an asynchronous withdrawal.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(WithdrawAsyncStatusResponse, Integer, Hash)>)

    WithdrawAsyncStatusResponse data, response status code and response headers



509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
# File 'lib/jamm/api/api/payment_api.rb', line 509

def internal_withdraw_async_status_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PaymentApi.internal_withdraw_async_status ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling PaymentApi.internal_withdraw_async_status"
  end
  # resource path
  local_var_path = '/v1/withdraw/async/status'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'WithdrawAsyncStatusResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"PaymentApi.internal_withdraw_async_status",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentApi#internal_withdraw_async_status\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#internal_withdraw_async_with_http_info(body, opts = {}) ⇒ Array<(WithdrawAsyncResponse, Integer, Hash)>

Initiate async withdraw (internal) Internal-only endpoint for initiating asynchronous withdrawal processing.

Parameters:

  • body (WithdrawAsyncRequest)

    This message represents a request to withdraw money from a customer asynchronously. It contains the customer ID and the amount to withdraw. Supports triggerError in charge.metadata for test error simulation. See InitialCharge.metadata.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(WithdrawAsyncResponse, Integer, Hash)>)

    WithdrawAsyncResponse data, response status code and response headers



441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'lib/jamm/api/api/payment_api.rb', line 441

def internal_withdraw_async_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PaymentApi.internal_withdraw_async ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling PaymentApi.internal_withdraw_async"
  end
  # resource path
  local_var_path = '/v1/withdraw/async'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'WithdrawAsyncResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"PaymentApi.internal_withdraw_async",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentApi#internal_withdraw_async\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#off_session_payment(body, opts = {}) ⇒ OffSessionPaymentResponse

Process payment directly without redirect Execute a payment off-session within your application without redirecting to a payment page.

Parameters:

  • body (OffSessionPaymentRequest)

    This message represents a request to process a payment directly within the application. It contains the customer ID and charge details to be processed. Supports triggerError in charge.metadata for test error simulation. See InitialCharge.metadata.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



567
568
569
570
# File 'lib/jamm/api/api/payment_api.rb', line 567

def off_session_payment(body, opts = {})
  data, _status_code, _headers = off_session_payment_with_http_info(body, opts)
  data
end

#off_session_payment_with_http_info(body, opts = {}) ⇒ Array<(OffSessionPaymentResponse, Integer, Hash)>

Process payment directly without redirect Execute a payment off-session within your application without redirecting to a payment page.

Parameters:

  • body (OffSessionPaymentRequest)

    This message represents a request to process a payment directly within the application. It contains the customer ID and charge details to be processed. Supports triggerError in charge.metadata for test error simulation. See InitialCharge.metadata.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(OffSessionPaymentResponse, Integer, Hash)>)

    OffSessionPaymentResponse data, response status code and response headers



577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
# File 'lib/jamm/api/api/payment_api.rb', line 577

def off_session_payment_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PaymentApi.off_session_payment ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling PaymentApi.off_session_payment"
  end
  # resource path
  local_var_path = '/v1/payments/off-session'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'OffSessionPaymentResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"PaymentApi.off_session_payment",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentApi#off_session_payment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#on_session_payment(body, opts = {}) ⇒ OnSessionPaymentResponse

Process payment with optional redirect Unified interface for creating payments - supports existing customers, new customers with charges, and contract-only creation.

Parameters:

  • body (OnSessionPaymentRequest)

    Request message for the unified payment interface. The system intelligently routes the request to the appropriate payment method based on the provided parameters. Supports triggerError for test error simulation via the core InitiatePayment/ApprovePayment flow. See InitialCharge.metadata for details on behavior differences by stage.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



635
636
637
638
# File 'lib/jamm/api/api/payment_api.rb', line 635

def on_session_payment(body, opts = {})
  data, _status_code, _headers = on_session_payment_with_http_info(body, opts)
  data
end

#on_session_payment_with_http_info(body, opts = {}) ⇒ Array<(OnSessionPaymentResponse, Integer, Hash)>

Process payment with optional redirect Unified interface for creating payments - supports existing customers, new customers with charges, and contract-only creation.

Parameters:

  • body (OnSessionPaymentRequest)

    Request message for the unified payment interface. The system intelligently routes the request to the appropriate payment method based on the provided parameters. Supports triggerError for test error simulation via the core InitiatePayment/ApprovePayment flow. See InitialCharge.metadata for details on behavior differences by stage.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(OnSessionPaymentResponse, Integer, Hash)>)

    OnSessionPaymentResponse data, response status code and response headers



645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
# File 'lib/jamm/api/api/payment_api.rb', line 645

def on_session_payment_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PaymentApi.on_session_payment ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling PaymentApi.on_session_payment"
  end
  # resource path
  local_var_path = '/v1/payments/on-session'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'OnSessionPaymentResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"PaymentApi.on_session_payment",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentApi#on_session_payment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#refund(body, opts = {}) ⇒ RefundResponse

Refund a charge Refunds a charge. If the same-day cancellation window has not passed, cancels the charge directly. Otherwise, creates a bank transfer refund request.

Parameters:

  • body (RefundRequest)

    Request message for refunding a charge. The refund is always processed asynchronously. The final result is delivered via webhook (&#x60;refund_succeeded&#x60;).

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



703
704
705
706
# File 'lib/jamm/api/api/payment_api.rb', line 703

def refund(body, opts = {})
  data, _status_code, _headers = refund_with_http_info(body, opts)
  data
end

#refund_with_http_info(body, opts = {}) ⇒ Array<(RefundResponse, Integer, Hash)>

Refund a charge Refunds a charge. If the same-day cancellation window has not passed, cancels the charge directly. Otherwise, creates a bank transfer refund request.

Parameters:

  • body (RefundRequest)

    Request message for refunding a charge. The refund is always processed asynchronously. The final result is delivered via webhook (&#x60;refund_succeeded&#x60;).

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(RefundResponse, Integer, Hash)>)

    RefundResponse data, response status code and response headers



713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
# File 'lib/jamm/api/api/payment_api.rb', line 713

def refund_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PaymentApi.refund ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling PaymentApi.refund"
  end
  # resource path
  local_var_path = '/v1/refund'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'RefundResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"PaymentApi.refund",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentApi#refund\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#withdraw(body, opts = {}) ⇒ WithdrawResponse

Withdraw money from customer immediately, without redirect This call is synchronous. The money will be withdrawn immediately.

Parameters:

  • body (WithdrawRequest)

    This message represents a request to withdraw money from a customer. It contains the customer ID and the amount to withdraw. Supports triggerError in charge.metadata for test error simulation. See InitialCharge.metadata.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



771
772
773
774
# File 'lib/jamm/api/api/payment_api.rb', line 771

def withdraw(body, opts = {})
  data, _status_code, _headers = withdraw_with_http_info(body, opts)
  data
end

#withdraw_with_http_info(body, opts = {}) ⇒ Array<(WithdrawResponse, Integer, Hash)>

Withdraw money from customer immediately, without redirect This call is synchronous. The money will be withdrawn immediately.

Parameters:

  • body (WithdrawRequest)

    This message represents a request to withdraw money from a customer. It contains the customer ID and the amount to withdraw. Supports triggerError in charge.metadata for test error simulation. See InitialCharge.metadata.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(WithdrawResponse, Integer, Hash)>)

    WithdrawResponse data, response status code and response headers



781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
# File 'lib/jamm/api/api/payment_api.rb', line 781

def withdraw_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PaymentApi.withdraw ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling PaymentApi.withdraw"
  end
  # resource path
  local_var_path = '/v1/withdraw'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'WithdrawResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"PaymentApi.withdraw",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentApi#withdraw\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end